.. _api:

#############
API Reference
#############

This is an example on how to document the API of your own project.

.. currentmodule:: coverforest

Classifier
==========

.. autosummary::
   :toctree: generated/
   :template: class.rst

   CoverForestClassifier

Regressor
=========

.. autosummary::
   :toctree: generated/
   :template: class.rst

   CoverForestRegressor


metrics
=======

.. autosummary::
   :toctree: generated/
   :template: functions.rst

     metrics.average_interval_length_loss
     metrics.average_set_size_loss
     metrics.classification_coverage_score
     metrics.regression_coverage_score
